==> core-react-0.8.0.tgz: package/es/dialog/DialogButtons.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Button from '../Button';
import { typeMap } from './config';

var DialogButtons = /*#__PURE__*/function (_React$Component) {
  _inherits(DialogButtons, _React$Component);

  function DialogButtons(_props) {
    var _this;

    _classCallCheck(this, DialogButtons);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(DialogButtons).call(this));

    _defineProperty(_assertThisInitialized(_this), "handleClose", function () {
      var _this$context, _this$context$dialog, _this$context$dialog$, _this$props, _this$props$onClose;

      (_this$context = _this.context) === null || _this$context === void 0 ? void 0 : (_this$context$dialog = _this$context.dialog) === null || _this$context$dialog === void 0 ? void 0 : (_this$context$dialog$ = _this$context$dialog.close) === null || _this$context$dialog$ === void 0 ? void 0 : _this$context$dialog$.call(_this$context$dialog);
      (_this$props = _this.props) === null || _this$props === void 0 ? void 0 : (_this$props$onClose = _this$props.onClose) === null || _this$props$onClose === void 0 ? void 0 : _this$props$onClose.call(_this$props);

      _this.setState({
        open: false
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleAcceptClick", function () {
      _this.handleClose();

      setTimeout(function () {
        var _this$props2, _this$props2$onAccept;

        return (_this$props2 = _this.props) === null || _this$props2 === void 0 ? void 0 : (_this$props2$onAccept = _this$props2.onAccept) === null || _this$props2$onAccept === void 0 ? void 0 : _this$props2$onAccept.call(_this$props2);
      }, 400);
    });

    _defineProperty(_assertThisInitialized(_this), "handleCancelClick", function () {
      _this.handleClose();

      setTimeout(function () {
        var _this$props3, _this$props3$onCancel;

        return (_this$props3 = _this.props) === null || _this$props3 === void 0 ? void 0 : (_this$props3$onCancel = _this$props3.onCancel) === null || _this$props3$onCancel === void 0 ? void 0 : _this$props3$onCancel.call(_this$props3);
      }, 400);
    });

    _defineProperty(_assertThisInitialized(_this), "renderButtons", function (props) {
      var _typeMap$type;

      var className = props.className,
          acceptLabel = props.acceptLabel,
          cancelLabel = props.cancelLabel,
          type = props.type;
      return React.createElement("div", {
        className: cx("".concat("waui", "-dialog__main-buttons"), className)
      }, !!acceptLabel && React.createElement(Button, {
        type: ((_typeMap$type = typeMap[type]) === null || _typeMap$type === void 0 ? void 0 : _typeMap$type.btnType) || 'secondary',
        onClick: _this.handleAcceptClick,
        block: true
      }, acceptLabel), !!cancelLabel && React.createElement(Button, {
        onClick: _this.handleCancelClick,
        block: true
      }, cancelLabel));
    });

    _this.state = {
      open: true
    };
    return _this;
  }

  _createClass(DialogButtons, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      this.state.open === false && this.setState({
        open: true
      });
    }
  }, {
    key: "render",
    value: function render() {
      return this.state.open ? React.createElement("div", null, this.renderButtons(this.props)) : this.renderButtons(this.props);
    }
  }]);

  return DialogButtons;
}(React.Component);

_defineProperty(DialogButtons, "contextTypes", {
  dialog: PropTypes.object
});

_defineProperty(DialogButtons, "propTypes", {
  className: PropTypes.string,
  acceptLabel: PropTypes.string,
  cancelLabel: PropTypes.string,
  type: PropTypes.oneOf(['confirm', 'accept', 'warning', 'danger', 'success', 'info', 'error']),
  onClose: PropTypes.func,
  onAccept: PropTypes.func,
  onCancel: PropTypes.func
});

export default DialogButtons;

==> core-react-0.8.2.tgz: package/es/dialog/DialogButtons.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import Button from '../Button';
import { typeMap } from './config';

var DialogButtons = /*#__PURE__*/function (_React$Component) {
  _inherits(DialogButtons, _React$Component);

  function DialogButtons(_props) {
    var _this;

    _classCallCheck(this, DialogButtons);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(DialogButtons).call(this));

    _defineProperty(_assertThisInitialized(_this), "handleClose", function () {
      var _this$context, _this$context$dialog, _this$context$dialog$, _this$props, _this$props$onClose;

      (_this$context = _this.context) === null || _this$context === void 0 ? void 0 : (_this$context$dialog = _this$context.dialog) === null || _this$context$dialog === void 0 ? void 0 : (_this$context$dialog$ = _this$context$dialog.close) === null || _this$context$dialog$ === void 0 ? void 0 : _this$context$dialog$.call(_this$context$dialog);
      (_this$props = _this.props) === null || _this$props === void 0 ? void 0 : (_this$props$onClose = _this$props.onClose) === null || _this$props$onClose === void 0 ? void 0 : _this$props$onClose.call(_this$props);

      _this.setState({
        open: false
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleAcceptClick", function () {
      _this.handleClose();

      setTimeout(function () {
        var _this$props2, _this$props2$onAccept;

        return (_this$props2 = _this.props) === null || _this$props2 === void 0 ? void 0 : (_this$props2$onAccept = _this$props2.onAccept) === null || _this$props2$onAccept === void 0 ? void 0 : _this$props2$onAccept.call(_this$props2);
      }, 400);
    });

    _defineProperty(_assertThisInitialized(_this), "handleCancelClick", function () {
      _this.handleClose();

      setTimeout(function () {
        var _this$props3, _this$props3$onCancel;

        return (_this$props3 = _this.props) === null || _this$props3 === void 0 ? void 0 : (_this$props3$onCancel = _this$props3.onCancel) === null || _this$props3$onCancel === void 0 ? void 0 : _this$props3$onCancel.call(_this$props3);
      }, 400);
    });

    _defineProperty(_assertThisInitialized(_this), "renderButtons", function (props) {
      var _typeMap$type;

      var className = props.className,
          acceptLabel = props.acceptLabel,
          cancelLabel = props.cancelLabel,
          type = props.type;
      return (/*#__PURE__*/React.createElement("div", {
          className: cx("".concat("waui", "-dialog__main-buttons"), className)
        }, !!acceptLabel && /*#__PURE__*/React.createElement(Button, {
          type: ((_typeMap$type = typeMap[type]) === null || _typeMap$type === void 0 ? void 0 : _typeMap$type.btnType) || 'secondary',
          onClick: _this.handleAcceptClick,
          block: true
        }, acceptLabel), !!cancelLabel && /*#__PURE__*/React.createElement(Button, {
          onClick: _this.handleCancelClick,
          block: true
        }, cancelLabel))
      );
    });

    _this.state = {
      open: true
    };
    return _this;
  }

  _createClass(DialogButtons, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      this.state.open === false && this.setState({
        open: true
      });
    }
  }, {
    key: "render",
    value: function render() {
      return this.state.open ? /*#__PURE__*/React.createElement("div", null, this.renderButtons(this.props)) : this.renderButtons(this.props);
    }
  }]);

  return DialogButtons;
}(React.Component);

_defineProperty(DialogButtons, "contextTypes", {
  dialog: PropTypes.object
});

_defineProperty(DialogButtons, "propTypes", {
  className: PropTypes.string,
  acceptLabel: PropTypes.string,
  cancelLabel: PropTypes.string,
  type: PropTypes.oneOf(['confirm', 'accept', 'warning', 'danger', 'success', 'info', 'error']),
  onClose: PropTypes.func,
  onAccept: PropTypes.func,
  onCancel: PropTypes.func
});

export default DialogButtons;
